#
# spec file for package libgnome-keyring
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libgnome-keyring
Version:        3.12.0
Release:        9.8
Summary:        Library to integrate with the GNOME Keyring
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Development/Libraries/GNOME
URL:            http://www.gnome.org/
Source:         http://download.gnome.org/sources/libgnome-keyring/3.12/%{name}-%{version}.tar.xz
Source99:       baselibs.conf

BuildRequires:  dbus-1-devel
BuildRequires:  fdupes
BuildRequires:  glib2-devel
BuildRequires:  gobject-introspection-devel
BuildRequires:  intltool
BuildRequires:  libgcrypt-devel

%description
The GNOME Keyring is a program that keep password and other secrets
for users. The libgnome-keyring library is used by applications to
integrate with the GNOME Keyring system.

%package -n libgnome-keyring0
Summary:        Library to integrate with the GNOME Keyring
Group:          System/Libraries
Recommends:     gnome-keyring
# To make the lang package happy
Provides:       %{name} = %{version}

%description -n libgnome-keyring0
The GNOME Keyring is a program that keep password and other secrets
for users. The libgnome-keyring library is used by applications to
integrate with the GNOME Keyring system.

%package -n typelib-1_0-GnomeKeyring-1_0
Summary:        Library to integrate with the GNOME Keyring -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-GnomeKeyring-1_0
The GNOME Keyring is a program that keep password and other secrets
for users. The libgnome-keyring library is used by applications to
integrate with the GNOME Keyring system.

This package provides the GObject Introspection bindings for
libgnome-keyring.

%package devel
Summary:        Library to integrate with the GNOME Keyring - Development Files
Group:          Development/Libraries/GNOME
Requires:       libgnome-keyring0 = %{version}
Requires:       typelib-1_0-GnomeKeyring-1_0 = %{version}
Provides:       gnome-keyring-devel = %{version}
Obsoletes:      gnome-keyring-devel < %{version}
Provides:       gnome-keyring-doc = %{version}
Obsoletes:      gnome-keyring-doc < %{version}

%description devel
The GNOME Keyring is a program that keep password and other secrets
for users. The libgnome-keyring library is used by applications to
integrate with the GNOME Keyring system.

%lang_package

%prep
%setup -q

%build
%configure \
        --disable-static
make %{?_smp_mflags} V=1

%install
%make_install
%find_lang %{name}
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes %{buildroot}

%post -n libgnome-keyring0 -p /sbin/ldconfig
%postun -n libgnome-keyring0 -p /sbin/ldconfig

%files -n libgnome-keyring0
%license COPYING
%doc AUTHORS ChangeLog HACKING NEWS README
%{_libdir}/libgnome-keyring.so.*

%files -n typelib-1_0-GnomeKeyring-1_0
%{_libdir}/girepository-1.0/GnomeKeyring-1.0.typelib

%files devel
%{_datadir}/gir-1.0/GnomeKeyring-1.0.gir
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/gnome-keyring-1
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%{_datadir}/gtk-doc/html/gnome-keyring

%files lang -f %{name}.lang

%changelog
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Fri Aug 17 2018 bjorn.lie@gmail.com
- Drop vala BuildRequires: No longer build vala bindings.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed Feb  8 2017 dimstar@opensuse.org
- Drop the provides and obsoletes of gnome-keyring from
  baselibs.conf: the library does not provide all the capabilities
  gnome-keyring did. The package gnome-keyring-32bit still exists.
* Thu Jun 16 2016 dimstar@opensuse.org
- Add baselibs.conf to source list.
* Thu May  5 2016 hpj@suse.com
- Update for GNOME 3.20 (Fate#318572).
* Sun Mar 23 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Build fixes.
- Drop libgnome-keyring-deprecated.patch: Fixed upstream.
* Mon Mar 17 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + This library is now deprecated.
- Add libgnome-keyring-deprecated.patch: Fix headers: the
  deprecation was quite broken.
* Thu Oct 17 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Updated translations.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Build fixes.
* Wed May  1 2013 dimstar@opensuse.org
- Update to version 3.9.1:
  + Build fixes and tweaks.
* Mon Mar 25 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Mon Mar 18 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Updated translations.
* Mon Mar  4 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + Build fixes (bgo#691343).
- Drop libgnome-keyring-vapi.patch: fixed upstream.
* Mon Feb  4 2013 dimstar@opensuse.org
- Update to version 3.7.5:
  + Build fixes.
  + Updated translations.
- Rebase libgnome-keyring-vapi.patch: part of it was merged.
* Sat Nov 24 2012 dimstar@opensuse.org
- Update to version 3.7.2:
  + Share the secure memory pool with libsecret and gcr.
  + Other minor tweaks.
- Add libgnome-keyring-vapi.patch: fix installation of vapi files.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Updated translations.
* Fri Aug 17 2012 dimstar@opensuse.org
- Update to version 3.5.6:
  + More warnings about attributes not being stored secretly
  + Build fixes
  + Updated translations.
* Wed Aug  8 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + Vala bindings.
- Drop xz BuildRequires, as it now comes for free in the build
  system.
- Add vala BuildRequires in order to build the new vala bindings.
* Mon Jun 25 2012 dimstar@opensuse.org
- Update to version 3.5.3:
  + Fix debugging for G_MESSAGES_DEBUG.
  + Some minor fixes to avoid vala regression.
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 3.4.1:
  + Build fixes
  + Fix copyright headers
  + Updated translations.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + No changes.
* Tue Mar 20 2012 vuntz@opensuse.org
- Update to version 3.3.92:
  + Updated translations.
* Fri Mar  9 2012 dimstar@opensuse.org
- Update to version 3.3.91:
  + GObject introspection fixes.
  + Build fixes.
* Sun Feb  5 2012 dimstar@opensuse.org
- Update to version 3.3.5:
  + GObject introspection for synchronous functions
  + Fix issue where an operation could be completed twice, with
    undefined results.
  + Test against mock Secret Service rather than
    gnome-keyring-daemon
  + More testing fixes
  + Build fixes
  + Updated translations.
- Add gobject-introspection-devel to build introspection support.
- Split typelib file into typelib-1_0-GnomeKeyring-1_0 and add this
  package as Requires to the -devel package.
- Change RPM Group of libgnome-keyrin0 to System/Libraries.
- Drop glib2-devel Requires from the -devel package: it is
  automatically added the pkgconfig() way.
* Mon Jan 16 2012 vuntz@opensuse.org
- Update to version 3.3.4:
  + Fix gnome_keyring_item_info_copy()
  + Build fixes
* Mon Dec 19 2011 vuntz@opensuse.org
- Update to version 3.3.3:
  + Add tool to play with default keyring setting
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Tue Nov 15 2011 vuntz@opensuse.org
- Update to version 3.2.2:
  + Make sure to return find results in original order from daemon
  + Fill in the gnome_keyring_item_info_get_mtime() field correctly
* Sun Sep 25 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Updated translations.
* Sun Sep 18 2011 vuntz@opensuse.org
- Update to version 3.1.92:
  + Make sure we initialize dbus thread primitives.
  + Print warning when we get kicked off the bus for some reason.
  + Properly send the Type property when a new item is created.
  + Testing fixes.
* Tue Aug 30 2011 vuntz@opensuse.org
- Update to version 3.1.90:
  + Test and build fixes.
* Mon Jul 25 2011 vuntz@opensuse.org
- Update to version 3.1.4:
  + Merge 3.0.x changes:
  - Fix memory leak.
  - Add test tool for unlocking keyrings.
  - Fix crasher for memory leak fix.
  - Build fixes.
  + Test and build fixes.
* Tue May 17 2011 dimstar@opensuse.org
- Update to version 3.1.1:
  + Build fixes.
* Tue Apr 26 2011 fcrozat@novell.com
- Update to version 3.0.1:
  + Better testing configure options: --enable-tests=yes/no/full.
  + Cleanup documentation warnings.
  + Better fix for dbus threading race condition.
  + Add some code to debug to syslog in emergency situations.
  + Add debugging instrumentation to operations.
* Mon Apr  4 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + Updated translations.
* Mon Mar 21 2011 fcrozat@novell.com
- Update to version 2.91.93:
  + Use full interface.Property form for CreateCollection and
    CreateItem in the DBus API.
  + Fix crash in certain dbus corner cases.
* Thu Mar 10 2011 fcrozat@novell.com
- Update to version 2.91.92:
  + Use HKDF for hashing of key used to transport secrets.
  + Fix race condition when multiple applications try to create the
    default keyring at once.
  + Use a longer DBus timeout when tests are enabled.
  + Send content-type along with each secret. This is currently
    stubbed out and not exposed in the API.
  + Refactor tests.
  + Don't run tests if testing in gnome-keyring-daemon is not
    enabled.
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Tue Nov 23 2010 aj@suse.de
- Change lang package Requires to Recommends also for
  libgnome-keyring0.
* Tue Sep 28 2010 aj@suse.de
- Change lang package Requires to Recommends since it is not
  mandatory at runtime.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 2.32.0:
  + Make builds silent by default.
* Sun Sep 12 2010 vuntz@opensuse.org
- Update to version 2.31.92:
  + Require automake 1.7
  + Fix assertion in secure memory code.
  + Don't try to run daemon tests if DBus is not running.
  + Fix build warnings on ARM
* Mon Aug 30 2010 vuntz@opensuse.org
- Update to version 2.31.91:
  + Use newer tar version for tarballs so we don't truncate file
    names.
  + Remove erroneous egg-dbus dependency.
  + Try to fix broken use on multiple threads in libgnome-keyring.
  + Fix encoding problems with keyring names that contain foreign
    chars.
  + Memory leak fix.
- Remove sed hack to remove eggdbus dependency.
* Thu Aug 26 2010 vuntz@opensuse.org
- Remove bogus eggdbus dependency: remove eggdbus-devel
  BuildRequires and sed it out of configure. Note that it was
  removed this way upstream already.
* Thu Apr 29 2010 dimstar@opensuse.org
- Update to version 2.30.1:
  + Work around for bug in dbus which causes an endless loop during
    blocking operations.
  + Updated translations.
* Tue Mar 30 2010 vuntz@opensuse.org
- Update to version 2.30.0:
  + Fix assertion calling deprecated acl function.
  + Clear the client's session when the service disconnects.
  + Implement setting of Type property in
    gnome_keyring_item_set_info().
  + Allow predictable testing by setting up a test path and
    service.
  + Fix assertion when password is not found.
  + Prompt to create a new default keyring when creating an item
    while no default keyring exists.
  + Try to return GNOME_KEYRING_ALREADY_EXISTS where possible.
  + Hold reference to operation while waiting for prompt result.
  + Don't assert on va_list, which isn't necessarily a pointer.
  + Return GNOME_KEYRING_RESULT_NO_MATCH when no secret is found.
  + Fix up some documentation errors.
  + Updated translations.
- Drop libgnome-keyring-no-match.patch: fixed upstream.
- Create lang package.
* Tue Feb 16 2010 vuntz@opensuse.org
- Add libgnome-keyring-no-match.patch, taken from upstream to
  finally make usage of gnome-keyring work.
* Tue Dec 22 2009 vuntz@opensuse.org
- New package, based on gnome-keyring package. The library was
  split from there.
- Make the devel package Provide/Obsolete gnome-keyring-devel,
  since this is what is usually expected.
